# bf25_pycounts
[![codecov](https://codecov.io/github/bfrizzell01/bf25_pycounts/graph/badge.svg?token=DJ8A1JHO4X)](https://codecov.io/github/bfrizzell01/bf25_pycounts)
[![Documentation Status](https://readthedocs.org/projects/bf25-pycounts/badge/?version=latest)](https://bf25-pycounts.readthedocs.io/en/latest/?badge=latest)


Calculate word counts in a text file!

Author: Benjamin Frizzell

## Installation

```bash
$ pip install bf25_pycounts
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`bf25_pycounts` was created by Benjamin Frizzell. It is licensed under the terms of the MIT license.

## Credits

`bf25_pycounts` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
